---
name: Documentation Improvement
about: Proposed changes to the documentation
title: "[Doc]"
labels: documentation
assignees: ''

---

# Is anything incorrect?
Usually, when a change is proposed to the documentation it is because we forgot to update it, and documentation rot took hold.
Please let us know what you found to be incorrect, if applicable.

# Is anything missing?
Sometimes, you want an explanation for a particular piece of code, or an example for how to use something, that is simply not there.
Please let us know what you'd like to see, and we can try to write it!

# Can something be improved?
It isn't very often that someone takes the time to help us improve our documentation when something is there and presented correctly, but could be better.
Thank you for taking the time to let us know! Please give us a suggestion for what we could improve next, or even better, open a pull request with your changes! We'd love for you to help out with either of these methods.
